@@ -36,10 +36,7 @@ class Automaton(ResourceModule.Struct):
             returnValue = task.do()
         except Exception, e:
             exceptionType, exceptionValue, exceptionTraceback = sys.exc_info()
-            #import StringIO
-            #strio = StringIO.StringIO()
-            # traceback.print_stack(file=strio)
-            # kwds['exception stack trace'] = strio.getvalue()
+
             taskWorkRequest = task.workRequest()
 
             taskWorkRequest.kwds['exception type'] = str(exceptionType)
@@ -51,7 +48,7 @@ class Automaton(ResourceModule.Struct):
 
             raise
         
-        return returnValue
+        return 
     
     @staticmethod
     def compositeTaskCompleteCallback(request, result):
@@ -165,6 +162,13 @@ class Automaton(ResourceModule.Struct):
         
         threadpool = self.getThreadPoolUsingRequest(request)
 
+        if threadpool.isEmpty():
+            raise ErrorModule.ExecutionError(
+                'need to start thread before execution')
+
+        # now set the thread pool in the request
+        request.kwds['thread pool'] = threadpool
+
         threadpool.putRequest(request)
         
         if shouldWait:
@@ -236,10 +240,13 @@ class Automaton(ResourceModule.Struct):
             exc_callback = exc_callback
         )
 
+        task.workRequest(request)
+
         return request
 
 
-    def executePomset(self, task=None, pomset=None, requestKwds=None):
+    def executePomset(self, task=None, pomset=None, requestKwds=None,
+                      shouldWait=True):
 
         # create a new task
         # we assume that the pomset is a composite definition
@@ -261,21 +268,15 @@ class Automaton(ResourceModule.Struct):
 
         # check if any threads have been started
         try:
-            threadpool = self.getThreadPoolUsingRequest(request)
             """
+            threadpool = self.getThreadPoolUsingRequest(request)
             should be moved to the cloud automaton's getThreadPoolUsingRequest
             if threadpool.isEmpty():
                 raise ExecuteErrorModule.ExecutionError(
                     'need to start thread before execution')
             """
 
-
-            # now set the thread pool in the request
-            request.kwds['thread pool'] = threadpool
-
-            task.workRequest(request)
-
-            self.enqueueRequest(request)
+            self.enqueueRequest(request, shouldWait=shouldWait)
         except ValueError, e:
             logging.error(e)
             raise ExecuteErrorModule.ExecutionError(e)
