@@ -19,7 +19,16 @@ class Builder(object):
         nodeToEdit.setParameterBinding(parameterToEdit.id(), value)
         return
 
+    def removePomsetParameter(self, pomset, parameterName):
 
+        if parameterName in [DefinitionModule.Definition.SYMBOL_INPUT_TEMPORAL,
+                             DefinitionModule.Definition.SYMBOL_OUTPUT_TEMPORAL]:
+            raise ValueError('cannot remove parameters defined by the system')
+
+        parameter = pomset.getParameter(parameterName)
+        pomset.removeParameter(parameter)
+        return
+        
     def addPomsetParameter(self, pomset, parameterName, attributes):
 
         # the direction has to be specified
@@ -69,7 +78,8 @@ class Builder(object):
             id=parameterName, 
             optional=isOptional, active=isActive,
             portDirection=direction)
-        
+        parameter.name(parameterName)
+
         ParameterModule.setAttributes(parameter, parameterAttributes)
 
         pomset.addParameter(parameter)
@@ -97,7 +107,7 @@ class Builder(object):
 
     def createNewAtomicPomset(self, name=None, 
                               executableObject=None,
-                              staticArgs=None, *args, **kwds):
+                              *args, **kwds):
 
         newAtomicPomset = DefinitionModule.AtomicDefinition(*args, **kwds)
         if name is None:
@@ -343,6 +353,11 @@ class Builder(object):
             
         else:
     
+            # TODO:
+            # need to check whether the output parameter
+            # already as a blackboard parameter connected to it
+            # if so, will need to use that instead
+
             # create a blackboard parameter
             bbParameterId = '%s.%s-%s.%s' % (sourceNode.name(),
                                              sourceParameterId,
