@@ -6,6 +6,7 @@ import threadpool
 import unittest
 import logging
 
+import pomsets.builder as BuilderModule
 import pomsets.command as TaskCommandModule
 import pomsets.context as ContextModule
 import pomsets.definition as DefinitionModule
@@ -246,6 +247,7 @@ def createPomsetContainingParameterSweep():
     reducerNode.isCritical(True)
     reducerNode.name('reducer')
 
+    """
     blackboardParameter = \
         ParameterModule.BlackboardParameter('intermediate file')
     compositeDefinition.addParameter(blackboardParameter)
@@ -262,7 +264,18 @@ def createPomsetContainingParameterSweep():
         mapperNode, 'temporal output',
         reducerNode, 'temporal input',
     )
-    
+    """
+    builder = BuilderModule.Builder()
+    builder.connect(
+        compositeDefinition,
+        mapperNode, 'output file',
+        reducerNode, 'input files')
+    builder.connect(
+        compositeDefinition,
+        mapperNode, 'temporal output',
+        reducerNode, 'temporal input',
+        )
+
     compositeDefinition.name('basic map-reduce')
     
     return compositeDefinition
@@ -287,8 +300,11 @@ def bindParameterSweepDefinitionParameters(definition):
     (dataNode, parameterToEdit) = \
      mapperNode.getParameterToEdit('output file')
 
+    valuesToBind = ['/tmp/pomsets/count1', '/tmp/pomsets/count2']
     dataNode.setParameterBinding(parameterToEdit.id(),
-                                 ['/tmp/pomsets/count1', '/tmp/pomsets/count2'])
+                                 valuesToBind)
+
+
     (dataNode, parameterToEdit) = \
      reducerNode.getParameterToEdit('output file')
     dataNode.setParameterBinding(parameterToEdit.id(), ['/tmp/pomsets/count_all'])
